==> tuia-ecb-center-api-1.0.0.0-20190409.032612-25-sources.jar: cn/com/duiba/tuia/ecb/center/dto/WithdrawOrderDto.java <==
package cn.com.duiba.tuia.ecb.center.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2019/4/9.
 */
public class WithdrawOrderDto implements Serializable {
    private Integer id;

    private Long serialNumber;

    private Long changeSerialNumber;

    private Long fee;

    private Long userId;

    private Integer channel;

    private String payeeName;

    private String payeeAccount;

    private String payeeRemark;

    private Integer withdrawStatus;

    private Boolean alipayWithdrawStatus;

    private String alipayFallBack;

    private Date gmtCreate;

    private Date gmtModified;

    private String turnDownNote;

    private Long turnDownSerialNumber;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getSerialNumber() {
        return serialNumber;
    }

    public void setSerialNumber(Long serialNumber) {
        this.serialNumber = serialNumber;
    }

    public Long getChangeSerialNumber() {
        return changeSerialNumber;
    }

    public void setChangeSerialNumber(Long changeSerialNumber) {
        this.changeSerialNumber = changeSerialNumber;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getChannel() {
        return channel;
    }

    public void setChannel(Integer channel) {
        this.channel = channel;
    }

    public String getPayeeName() {
        return payeeName;
    }

    public void setPayeeName(String payeeName) {
        this.payeeName = payeeName;
    }

    public String getPayeeAccount() {
        return payeeAccount;
    }

    public void setPayeeAccount(String payeeAccount) {
        this.payeeAccount = payeeAccount;
    }

    public String getPayeeRemark() {
        return payeeRemark;
    }

    public void setPayeeRemark(String payeeRemark) {
        this.payeeRemark = payeeRemark;
    }

    public Integer getWithdrawStatus() {
        return withdrawStatus;
    }

    public void setWithdrawStatus(Integer withdrawStatus) {
        this.withdrawStatus = withdrawStatus;
    }

    public Boolean getAlipayWithdrawStatus() {
        return alipayWithdrawStatus;
    }

    public void setAlipayWithdrawStatus(Boolean alipayWithdrawStatus) {
        this.alipayWithdrawStatus = alipayWithdrawStatus;
    }

    public String getAlipayFallBack() {
        return alipayFallBack;
    }

    public void setAlipayFallBack(String alipayFallBack) {
        this.alipayFallBack = alipayFallBack;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTurnDownNote() {
        return turnDownNote;
    }

    public void setTurnDownNote(String turnDownNote) {
        this.turnDownNote = turnDownNote;
    }

    public Long getTurnDownSerialNumber() {
        return turnDownSerialNumber;
    }

    public void setTurnDownSerialNumber(Long turnDownSerialNumber) {
        this.turnDownSerialNumber = turnDownSerialNumber;
    }
}

==> tuia-ecb-center-api-1.0.0.2-20190417.043028-12-sources.jar: cn/com/duiba/tuia/ecb/center/dto/WithdrawOrderDto.java <==
package cn.com.duiba.tuia.ecb.center.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2019/4/9.
 */
public class WithdrawOrderDto implements Serializable {
    private Integer id;

    private Long serialNumber;

    private Long changeSerialNumber;

    private Long fee;

    private Long userId;

    private Integer channel;

    private String payeeName;

    private String payeeAccount;

    private String payeeRemark;

    private Integer withdrawStatus;

    private Integer alipayWithdrawStatus;

    private String alipayFallBack;

    private Date gmtCreate;

    private Date gmtModified;

    private String turnDownNote;

    private Long turnDownSerialNumber;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getSerialNumber() {
        return serialNumber;
    }

    public void setSerialNumber(Long serialNumber) {
        this.serialNumber = serialNumber;
    }

    public Long getChangeSerialNumber() {
        return changeSerialNumber;
    }

    public void setChangeSerialNumber(Long changeSerialNumber) {
        this.changeSerialNumber = changeSerialNumber;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getChannel() {
        return channel;
    }

    public void setChannel(Integer channel) {
        this.channel = channel;
    }

    public String getPayeeName() {
        return payeeName;
    }

    public void setPayeeName(String payeeName) {
        this.payeeName = payeeName;
    }

    public String getPayeeAccount() {
        return payeeAccount;
    }

    public void setPayeeAccount(String payeeAccount) {
        this.payeeAccount = payeeAccount;
    }

    public String getPayeeRemark() {
        return payeeRemark;
    }

    public void setPayeeRemark(String payeeRemark) {
        this.payeeRemark = payeeRemark;
    }

    public Integer getWithdrawStatus() {
        return withdrawStatus;
    }

    public void setWithdrawStatus(Integer withdrawStatus) {
        this.withdrawStatus = withdrawStatus;
    }

    public Integer getAlipayWithdrawStatus() {
        return alipayWithdrawStatus;
    }

    public void setAlipayWithdrawStatus(Integer alipayWithdrawStatus) {
        this.alipayWithdrawStatus = alipayWithdrawStatus;
    }

    public String getAlipayFallBack() {
        return alipayFallBack;
    }

    public void setAlipayFallBack(String alipayFallBack) {
        this.alipayFallBack = alipayFallBack;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTurnDownNote() {
        return turnDownNote;
    }

    public void setTurnDownNote(String turnDownNote) {
        this.turnDownNote = turnDownNote;
    }

    public Long getTurnDownSerialNumber() {
        return turnDownSerialNumber;
    }

    public void setTurnDownSerialNumber(Long turnDownSerialNumber) {
        this.turnDownSerialNumber = turnDownSerialNumber;
    }
}
